# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import enum_pb2 as enum__pb2
from . import message_pb2 as message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12\x07service\x1a\x1bgoogle/protobuf/empty.proto\x1a\nenum.proto\x1a\rmessage.proto\"s\n\x0eRunGameRequest\x12\x13\n\x0b\x63haracter_1\x18\x01 \x01(\t\x12\x13\n\x0b\x63haracter_2\x18\x02 \x01(\t\x12\x10\n\x08player_1\x18\x03 \x01(\t\x12\x10\n\x08player_2\x18\x04 \x01(\t\x12\x13\n\x0bgame_number\x18\x05 \x01(\x05\"\x11\n\x0fSpectateRequest\"\xf1\x01\n\x12SpectatorGameState\x12%\n\nstate_flag\x18\x01 \x01(\x0e\x32\x11.service.GrpcFlag\x12*\n\nframe_data\x18\x02 \x01(\x0b\x32\x16.service.GrpcFrameData\x12,\n\x0bscreen_data\x18\x03 \x01(\x0b\x32\x17.service.GrpcScreenData\x12*\n\naudio_data\x18\x04 \x01(\x0b\x32\x16.service.GrpcAudioData\x12.\n\x0cround_result\x18\x05 \x01(\x0b\x32\x18.service.GrpcRoundResult\"Q\n\x11InitializeRequest\x12\x15\n\rplayer_number\x18\x01 \x01(\x08\x12\x13\n\x0bplayer_name\x18\x02 \x01(\t\x12\x10\n\x08is_blind\x18\x03 \x01(\x08\")\n\x12InitializeResponse\x12\x13\n\x0bplayer_uuid\x18\x01 \x01(\t\")\n\x12ParticipateRequest\x12\x13\n\x0bplayer_uuid\x18\x01 \x01(\t\"\xe2\x02\n\x0fPlayerGameState\x12%\n\nstate_flag\x18\x01 \x01(\x0e\x32\x11.service.GrpcFlag\x12\x12\n\nis_control\x18\x02 \x01(\x08\x12*\n\nframe_data\x18\x03 \x01(\x0b\x32\x16.service.GrpcFrameData\x12\x34\n\x14non_delay_frame_data\x18\x04 \x01(\x0b\x32\x16.service.GrpcFrameData\x12,\n\x0bscreen_data\x18\x05 \x01(\x0b\x32\x17.service.GrpcScreenData\x12*\n\naudio_data\x18\x06 \x01(\x0b\x32\x16.service.GrpcAudioData\x12(\n\tgame_data\x18\x07 \x01(\x0b\x32\x15.service.GrpcGameData\x12.\n\x0cround_result\x18\x08 \x01(\x0b\x32\x18.service.GrpcRoundResult\"G\n\x0bPlayerInput\x12\x13\n\x0bplayer_uuid\x18\x01 \x01(\t\x12#\n\tinput_key\x18\x02 \x01(\x0b\x32\x10.service.GrpcKey2\xda\x02\n\x07Service\x12<\n\x07RunGame\x12\x17.service.RunGameRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x45\n\x08Spectate\x12\x18.service.SpectateRequest\x1a\x1b.service.SpectatorGameState\"\x00\x30\x01\x12G\n\nInitialize\x12\x1a.service.InitializeRequest\x1a\x1b.service.InitializeResponse\"\x00\x12H\n\x0bParticipate\x12\x1b.service.ParticipateRequest\x1a\x18.service.PlayerGameState\"\x00\x30\x01\x12\x37\n\x05Input\x12\x14.service.PlayerInput\x1a\x16.google.protobuf.Empty\"\x00\x42\x1e\n\x06protocB\x0cServiceProtoP\x00\xa2\x02\x03HLWb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\006protocB\014ServiceProtoP\000\242\002\003HLW'
  _RUNGAMEREQUEST._serialized_start=82
  _RUNGAMEREQUEST._serialized_end=197
  _SPECTATEREQUEST._serialized_start=199
  _SPECTATEREQUEST._serialized_end=216
  _SPECTATORGAMESTATE._serialized_start=219
  _SPECTATORGAMESTATE._serialized_end=460
  _INITIALIZEREQUEST._serialized_start=462
  _INITIALIZEREQUEST._serialized_end=543
  _INITIALIZERESPONSE._serialized_start=545
  _INITIALIZERESPONSE._serialized_end=586
  _PARTICIPATEREQUEST._serialized_start=588
  _PARTICIPATEREQUEST._serialized_end=629
  _PLAYERGAMESTATE._serialized_start=632
  _PLAYERGAMESTATE._serialized_end=986
  _PLAYERINPUT._serialized_start=988
  _PLAYERINPUT._serialized_end=1059
  _SERVICE._serialized_start=1062
  _SERVICE._serialized_end=1408
# @@protoc_insertion_point(module_scope)
