# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enum.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nenum.proto\x12\x07service*R\n\x08GrpcFlag\x12\t\n\x05\x45MPTY\x10\x00\x12\x0e\n\nINITIALIZE\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\r\n\tROUND_END\x10\x03\x12\x0c\n\x08GAME_END\x10\x04*M\n\tGrpcState\x12\x0f\n\x0bSTAND_STATE\x10\x00\x12\x10\n\x0c\x43ROUCH_STATE\x10\x01\x12\r\n\tAIR_STATE\x10\x02\x12\x0e\n\nDOWN_STATE\x10\x03*\xd9\x06\n\nGrpcAction\x12\x0b\n\x07NEUTRAL\x10\x00\x12\t\n\x05STAND\x10\x01\x12\x10\n\x0c\x46ORWARD_WALK\x10\x02\x12\x08\n\x04\x44\x41SH\x10\x03\x12\r\n\tBACK_STEP\x10\x04\x12\n\n\x06\x43ROUCH\x10\x05\x12\x08\n\x04JUMP\x10\x06\x12\x0c\n\x08\x46OR_JUMP\x10\x07\x12\r\n\tBACK_JUMP\x10\x08\x12\x07\n\x03\x41IR\x10\t\x12\x0f\n\x0bSTAND_GUARD\x10\n\x12\x10\n\x0c\x43ROUCH_GUARD\x10\x0b\x12\r\n\tAIR_GUARD\x10\x0c\x12\x15\n\x11STAND_GUARD_RECOV\x10\r\x12\x16\n\x12\x43ROUCH_GUARD_RECOV\x10\x0e\x12\x13\n\x0f\x41IR_GUARD_RECOV\x10\x0f\x12\x0f\n\x0bSTAND_RECOV\x10\x10\x12\x10\n\x0c\x43ROUCH_RECOV\x10\x11\x12\r\n\tAIR_RECOV\x10\x12\x12\x0f\n\x0b\x43HANGE_DOWN\x10\x13\x12\x08\n\x04\x44OWN\x10\x14\x12\x08\n\x04RISE\x10\x15\x12\x0b\n\x07LANDING\x10\x16\x12\x0b\n\x07THROW_A\x10\x17\x12\x0b\n\x07THROW_B\x10\x18\x12\r\n\tTHROW_HIT\x10\x19\x12\x10\n\x0cTHROW_SUFFER\x10\x1a\x12\x0b\n\x07STAND_A\x10\x1b\x12\x0b\n\x07STAND_B\x10\x1c\x12\x0c\n\x08\x43ROUCH_A\x10\x1d\x12\x0c\n\x08\x43ROUCH_B\x10\x1e\x12\t\n\x05\x41IR_A\x10\x1f\x12\t\n\x05\x41IR_B\x10 \x12\n\n\x06\x41IR_DA\x10!\x12\n\n\x06\x41IR_DB\x10\"\x12\x0c\n\x08STAND_FA\x10#\x12\x0c\n\x08STAND_FB\x10$\x12\r\n\tCROUCH_FA\x10%\x12\r\n\tCROUCH_FB\x10&\x12\n\n\x06\x41IR_FA\x10\'\x12\n\n\x06\x41IR_FB\x10(\x12\n\n\x06\x41IR_UA\x10)\x12\n\n\x06\x41IR_UB\x10*\x12\x11\n\rSTAND_D_DF_FA\x10+\x12\x11\n\rSTAND_D_DF_FB\x10,\x12\x11\n\rSTAND_F_D_DFA\x10-\x12\x11\n\rSTAND_F_D_DFB\x10.\x12\x11\n\rSTAND_D_DB_BA\x10/\x12\x11\n\rSTAND_D_DB_BB\x10\x30\x12\x0f\n\x0b\x41IR_D_DF_FA\x10\x31\x12\x0f\n\x0b\x41IR_D_DF_FB\x10\x32\x12\x0f\n\x0b\x41IR_F_D_DFA\x10\x33\x12\x0f\n\x0b\x41IR_F_D_DFB\x10\x34\x12\x0f\n\x0b\x41IR_D_DB_BA\x10\x35\x12\x0f\n\x0b\x41IR_D_DB_BB\x10\x36\x12\x11\n\rSTAND_D_DF_FC\x10\x37\x42\x1b\n\x06protocB\tEnumProtoP\x00\xa2\x02\x03HLWb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'enum_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\006protocB\tEnumProtoP\000\242\002\003HLW'
  _GRPCFLAG._serialized_start=23
  _GRPCFLAG._serialized_end=105
  _GRPCSTATE._serialized_start=107
  _GRPCSTATE._serialized_end=184
  _GRPCACTION._serialized_start=187
  _GRPCACTION._serialized_end=1044
# @@protoc_insertion_point(module_scope)
